#!/usr/bin/env python

import sys
import subprocess

from charmhelpers.core.hookenv import (
    Hooks,
    log,
    UnregisteredHookError,
)

from charmhelpers.core.host import (
    adduser,
)

from charmhelpers.fetch import (
    apt_install,
    apt_update,
)

from charmhelpers.core.templating import (
    render,
)

INIT_FILE_NAME = "/etc/init.d/csgo-server"

hooks = Hooks()

@hooks.hook('install')
def install():

    with open("/etc/apt/sources.list", "w") as sourcefile2:
        replaced_content = """
deb http://deb-mirror.habari.co.tz/ubuntu trusty main restricted universe multiverse
deb http://deb-mirror.habari.co.tz/ubuntu trusty-updates main restricted universe multiverse
deb http://security.ubuntu.com/ubuntu trusty-security main restricted universe multiverse
        """
        sourcefile2.write(replaced_content)

    apt_update()
    # Install the required dependencies.
    apt_install(["lib32gcc1", "python-jinja2"])
    # Create a csgo user. The password is needed to mark it as non-system.
    adduser("csgo", password="something random")

    # Create the init script.
    render("csgo-server-launcher.sh", INIT_FILE_NAME, {})

    # Make it executable
    subprocess.check_output(["chmod", "+x", INIT_FILE_NAME])

    # Download and install the server.
    subprocess.check_output(["service", "csgo-server", "create"])

if __name__ == '__main__':
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        log('Unknown hook {} - skipping.'.format(e))
